@@ -13,23 +13,23 @@ p2 <- function() plot(mtcars$hp, mtcars$wt)
 # good plot
 # Run once to create the reference plot
 # Run twice to pass the test
-if (!ON_CRAN) {
-    expect_snapshot_plot(p1, "svglite-base")
-}
+expect_snapshot_plot(p1, "svglite-base")
 
 # bad plot always fails
-expect_false(ignore(expect_snapshot_plot)(p2, "svglite-base"))
+if (Sys.info()["sysname"] %in% getOption("tinysnapshot_os", default = Sys.info()["sysname"])) {
+    expect_false(ignore(expect_snapshot_plot)(p2, "svglite-base"))
+}
 
 ###### ggplot2
 suppressPackageStartupMessages(library("ggplot2"))
 
-if (!ON_CRAN) {
-    p1 <- ggplot(mtcars, aes(mpg, hp)) + geom_point()
-    expect_snapshot_plot(p1, "svglite-ggplot2_variable")
-}
+p1 <- ggplot(mtcars, aes(mpg, hp)) + geom_point()
+expect_snapshot_plot(p1, "svglite-ggplot2_variable")
 
-p2 <- ggplot(mtcars, aes(mpg, wt)) + geom_point()
-expect_false(ignore(expect_snapshot_plot)(p2, "svglite-ggplot2_variable"))
+if (Sys.info()["sysname"] %in% getOption("tinysnapshot_os", default = Sys.info()["sysname"])) {
+    p2 <- ggplot(mtcars, aes(mpg, wt)) + geom_point()
+    expect_false(ignore(expect_snapshot_plot)(p2, "svglite-ggplot2_variable"))
+}
 
 
 
